Publications
============
The following publications have been produced using BSK-RL and its predecessors. If you have used BSK-RL in your research, please let us know and we will add your publication to the list.


Journal Papers
--------------
#. \A. P. Herrmann and H. Schaub, `"Monte Carlo Tree Search Methods for the Earth-Observing Satellite Scheduling Problem," <https://hanspeterschaub.info/PapersPrivate/Herrmann2022b.pdf>`_ Journal of Aerospace Information Systems, Vol. 19, No. 1, January 2022, pp. 70–82. doi:10.2514/1.I010992.
#. \A. Harris, T. Valade, T. Teil and H. Schaub, `“Generation of Spacecraft Operations Procedures Using Deep Reinforcement Learning,” <https://hanspeterschaub.info/PapersPrivate/Harris2022a.pdf>`_ Journal of Spacecraft and Rockets, Vol. 59, No. 2, March–April 2022, pp. 611–626. doi:10.2514/1.A35169.
#. \A. P. Herrmann and H. Schaub, `“Reinforcement Learning for the Agile Earth-Observing Satellite Scheduling Problem,” <https://hanspeterschaub.info/PapersPrivate/Herrmann2023b.pdf>`_ IEEE Transactions of Aerospace and Electronic Systems, Vol. 59, No. 5, Oct. 2023, pp. 5235–5247. doi:10.1109/TAES.2023.3251307.
#. \A. Herrmann and H. Schaub, `“A Comparative Analysis of Reinforcement Learning Algorithms for Earth-Observing Satellite Scheduling,” <https://hanspeterschaub.info/PapersPrivate/Herrmann2023.pdf>`_ Frontiers in Space Technologies, November 29, 2023. doi:10.3389/frspt.2023.1263489.
#. \A. Herrmann, M. Stephenson and H. Schaub, `“Single-Agent Reinforcement Learning for Scalable Earth-Observing Satellite Constellation Operations,” <https://arc.aiaa.org/doi/10.2514/1.A35736>`_ Journal of Spacecraft and Rockets. doi:10.2514/1.A35736.
#. \A. Herrmann and H. Schaub, `“Autonomous Small Body Science Operations Using Reinforcement Learning,” <https://hanspeterschaub.info/PapersPrivate/Herrmann2024a.pdf>`_ Journal of Aerospace Information Systems, Vol. 21, No. 10, October 2024, pp. 865–884. doi:10.2514/1.I011376.
#. \M. Stephenson and H. Schaub, `“Optimal Agile Satellite Target Scheduling with Learned Dynamics,” <https://doi.org/10.2514/1.A36097>`_ Journal of Spacecraft and Rockets. doi:10.2514/1.A36097.
#. \M. Stephenson and H. Schaub, “On-board Policies for Autonomous Earth Observing Satellite Scheduling with semi-MDPs,” Journal of Aerospace Information Systems, accepted for publication.
#. \L. Quevedo Mantovani and H. Schaub, “Deep Reinforcement Learning for Satellite Autonomy with Cloud Coverage Uncertainty,” Journal of Aerospace Information Systems, manuscript submitted for publication.

Conference Papers
-----------------
#. \A. Harris. T. Teil and H. Schaub, `“Spacecraft Decision-Making Autonomy using Deep Reinforcement Learning,” <https://hanspeterschaub.info/Papers/Harris2019.pdf>`_ AAS Spaceflight Mechanics Meeting, Maui, Hawaii January 13–17, 2019.
#. \A. Harris and H. Schaub, `“Spacecraft Command and Control with Safety Guarantees using Shielded Deep Reinforcement Learning” <https://hanspeterschaub.info/Papers/Harris2020.pdf>`_ AIAA SciTech Forum, Orlando, Florida, Jan. 6–10, 2020.
#. \A. Herrmann and H. Schaub, `“Monte Carlo Tree Search With Value Networks For Autonomous Spacecraft Operations,” <https://hanspeterschaub.info/Papers/Herrmann2020.pdf>`_ AAS/AIAA Astrodynamics Specialist Conference, Lake Tahoe, CA, Aug. 9–13, 2020. 
#. \A. Herrmann and H. Schaub, `“Autonomous Spacecraft Tasking using Monte Carlo Tree Search Methods,” <https://hanspeterschaub.info/Papers/Herrmann2021b.pdf>`_ AAS/AIAA Space Flight Mechanics Meeting, Charlotte, NC, January 31–February 4, 2021. 
#. \A. Herrmann and H. Schaub, `“Autonomous On-board Planning for Earth-orbiting Spacecraft,” <https://hanspeterschaub.info/Papers/Herrmann2022a.pdf>`_ IEEE Aerospace Conference, Big Sky, MT, March 5–12, 2022. 
#. \I. Nazmy, A. Harris, M. Lahijanian and H. Schaub, `“Shielded Deep Reinforcement Learning for Multi-Sensor Spacecraft Imaging,” <https://hanspeterschaub.info/Papers/Nazmy2022.pdf>`_ American Control Conference, Atlanta, GA, June 8–10, 2022.
#. \A. Herrmann and H. Schaub, `“A Comparison Of Deep Reinforcement Learning Algorithms For Earth-Observing Satellite Scheduling,” <https://hanspeterschaub.info/Papers/Herrmann2023.pdf>`_ AAS/AIAA Spaceflight Mechanics Meeting, Austin, TX, Jan. 15–19, 2023.
#. \V. Bajenaru, A. Herrmann, H. Schaub and S. Philipps, `“Command and Control of Satellite Constellations using Explainable Deep Reinforcement Learning,” <https://hanspeterschaub.info/Papers/Bajenaru2023.pdf>`_ AAS Rocky Mountain GN&C Conference, Breckenridge, CO, Feb. 2–8, 2023.
#. \A. Herrmann, M. Stephenson and H. Schaub, `“Reinforcement Learning for Multi-Satellite Agile Earth Observing Scheduling Under Various Communication Assumptions,” <https://hanspeterschaub.info/Papers/Herrmann2023a.pdf>`_ AAS Rocky Mountain GN&C Conference, Breckenridge, CO, Feb. 2–8, 2023.
#. \A. Herrmann and H. Schaub, `“Reinforcement Learning For Small Body Science Operations,” <https://hanspeterschaub.info/Papers/Herrmann2022c.pdf>`_ AAS Astrodynamics Specialist Conference, Charlotte, North Carolina, August 7–10 2022, Paper No. AAS 22-563.
#. \M. Stephenson and H. Schaub, `“Optimal Target Sequencing In The Agile Earth-Observing Satellite Scheduling Problem Using Learned Dynamics,” <https://hanspeterschaub.info/Papers/Stephenson2023.pdf>`_ AAS/AIAA Astrodynamics Specialist Conference, Big Sky, Montana, August 13–17 2023. 
#. \M. Stephenson, L. Quevedo Mantovani, S. Phillips and H. Schaub, `“Using Enhanced Simulation Environments to Accelerate Reinforcement Learning for Long-Duration Satellite Autonomy,” <https://hanspeterschaub.info/Papers/Stephenson2024.pdf>`_ AIAA Science and Technology Forum and Exposition (SciTech), Orlando, Florida, Jan. 8–12, 2024. doi:10.2514/6.2024-0990.
#. \M. Stephenson and H. Schaub, `“Reinforcement Learning for Earth-Observing Satellite Autonomy with Event-Based Task Intervals,” <https://hanspeterschaub.info/Papers/Stephenson2024a.pdf>`_ AAS Rocky Mountain GN&C Conference, Breckenridge, CO, Feb. 2–7, 2024.
#. \M. Stephenson, L. Quevedo Mantovani and H. Schaub, `“Intent Sharing for Emergent Collaboration in Autonomous Earth Observing Constellations,” <https://hanspeterschaub.info/Papers/Stephenson2024b.pdf>`_ AAS Rocky Mountain GN&C Conference, Breckenridge, CO, Feb. 2–7, 2024.
#. \L. Quevedo Mantovani, Y. Nagano and H. Schaub, `“Reinforcement Learning For Satellite Autonomy Under Different Cloud Coverage Probability Observations,” <https://hanspeterschaub.info/Papers/Mantovani2024.pdf>`_ AAS Astrodynamics Specialist Conference, Broomfield, CO, Aug. 11–15 2024.
#. \M. Stephenson and H. Schaub, `“BSK-RL: Modular, High-Fidelity Reinforcement Learning Environments for Spacecraft Tasking,” <https://hanspeterschaub.info/Papers/Stephenson2024c.pdf>`_ International Astronautical Congress, Milan, Italy, Oct. 14–18 2024. 
#. \M. Stephenson and H. Schaub, `“Scalable Autonomous Decentralized Constellation Tasking on Asynchronous Semi-Markov Decision Processes,” <https://hanspeterschaub.info/Papers/Stephenson2024d.pdf>`_ International Workshop on Satellite Constellations & Formation Flying, Kaohsiung, Taiwan, December 2–4, 2024. 
#. \Y. Nagano and H. Schaub, `“Fault Resilience of Reinforcement-Based Satellite Autonomous Task Scheduling,” <https://hanspeterschaub.info/Papers/Nagano2025.pdf>`_ AAS Space Flight Mechanics Meeting, Kauai, HI, January 19–23, 2025.
#. \M. Stephenson, L. Quevedo Mantovani, A. Cheval and H. Schaub, `“Quantifying The Optimality Of A Distributed Rl-Based Autonomous Earth-Observing Constellation,” <https://hanspeterschaub.info/Papers/Stephenson2025.pdf>`_ AAS Guidance, Navigation and Control Conference, Breckenridge, CO, January 31 – February 5, 2025.
#. \L. Quevedo Mantovani and H. Schaub, `“Improving Robustness Of Autonomous Spacecraft Scheduling Using Curriculum Learning,” <https://hanspeterschaub.info/Papers/QuevedoMantovani2025.pdf>`_ AAS Guidance, Navigation and Control Conference, Breckenridge, CO, January 31 – February 5, 2025.
#. \M. Stephenson, D. Huterer Prats and H. Schaub, `“Autonomous Satellite Inspection in Low Earth Orbit with Optimization-Based Safety Guarantees,” <https://hanspeterschaub.info/Papers/Stephenson2025a.pdf>`_ International Workshop on Planning & Scheduling for Space, Toulouse, France, April 28–30, 2025.
#. \M. Stephenson, L. Quevedo Mantovani and H. Schaub, `“Achieving Near-Optimal Performance in Autonomous Earth Observing Satellite Scheduling using semi-MDPs,” <https://hanspeterschaub.info/Papers/Stephenson2025c.pdf>`_ International Workshop on Planning & Scheduling for Space, Toulouse, France, April 28–30, 2025.
#. \L. Quevedo Mantovani and H. Schaub, `“Performance Evaluation of Shielded Neural Networks for Autonomous Agile Earth Observing Satellites in Long Term Scenarios,” <https://hanspeterschaub.info/Papers/QuevedoMantovani2025a.pdf>`_ International Workshop on Planning & Scheduling for Space, Toulouse, France, April 28–30, 2025.
#. \M. A. Hady, S. Hu, M. Pratama, J. Cao, and R. Kowalczyk, `“Multi-Agent Reinforcement Learning for Autonomous Multi-Satellite Earth Observation: A Realistic Case Study,” <https://arxiv.org/abs/2506.15207>`_ arXiv preprint, June 2025.
#. \C. Whitney and J. Melville, `“Toward Trusted Onboard AI: Advancing Small Satellite Operations using Reinforcement Learning,” <https://www.arxiv.org/abs/2507.22198>`_ 39th Small Satellite Conference, Salt Lake City, UT, August 10-13, 2025.
#. \A. Cheval and H. Schaub, `“Reinforcement Learning For Autonomous Strip Imaging Task Scheduling In Super-Agile Satellites,” <https://hanspeterschaub.info/Papers/Cheval2025b.pdf>`_ AAS Astrodynamics Specialist Conference, Boston, Massachusetts, August 10–14, 2025.
#. \Y. Nagano and H. Schaub, `“Enhancing Fault Resilience In {RL}-Based Satellite Autonomous Task Scheduling,” <https://hanspeterschaub.info/Papers/Nagano2025a.pdf>`_ AAS Astrodynamics Specialist Conference, Boston, Massachusetts, August 10–14, 2025.
#. \D. Huterer Prats and H. Schaub, `“Reinforcement Learning for Space-to-Space Surveillance: Autonomous Scheduling for Resident Space Object Imaging,” <https://hanspeterschaub.info/Papers/Prats2025.pdf>`_ Advanced Maui Optical and Space Surveillance Technologies Conference, Maui, Hawaii, September 16–19, 2025.
#. \M. Stephenson and H. Schaub, `“Safe, Autonomous Multiagent Inspection of Space Objects Leveraging Relative Orbit Dynamics,” <https://hanspeterschaub.info/Papers/Stephenson2025b.pdf>`_ Advanced Maui Optical and Space Surveillance Technologies Conference, Maui, Hawaii, September 16–19, 2025.